MQ Torun, Poland May 31st 2008 3R+F 12 players Marcin Szybkowski (Dude) Deck Name: Along comes the spider Description: This deck won the mini qualifier in Torun, a local tournament in Warsaw, and managed to get into the final round during the Polish ECQ. it's a very solid deck against most archetypes, card flow is really impressive, and it does tend to be underestimated (not too often, but it happens). it's also a very fun deck to play, in the ideal setup you block out your predator while making constant pressure on your prey. Crypt (12 cards, min=15, max=32, avg=6.33) ------------------------------------------ 3x Nkule Galadima 8 ABO FOR ani aus pre magaji Akunanse:4 3x Uchenna 7 ABO ANI FOR magaji Akunanse:4 2x Amavi 8 ABO ANI FOR pre pro Akunanse:4 1x Jubal 6 ABO ANI for pot Akunanse:4 1x Hasani 4 ABO for Akunanse:4 1x Dolie 3 abo ani Akunanse:4 1x Meno Ngari 2 abo Akunanse:4 Library (90 cards) Master (16; 3 trifle) 1x Ancestor Spirit 2x Blood Doll 2x Direct Intervention -- I'm thinking about adding another one, this card is cruicial for any block denial actions, or things that simply screw your spiders 2x Dreams of the Sphinx 1x Giant's Blood 1x Jungle Hunting Ground 1x Legendary Vampire 1x Mbare Market, Harare 1x Powerbase: Tshwane -- there was some magic around this card, I got it in every single game, in the first 10 cards drawn 3x Vessel 1x WMRH Talk Radio -- didn't use it at all, metagame wasn't stealth heavy though Action (10) 1x Aranthebes, The Immortal 1x Army of Rats 3x Belonging Grants Protection 3x No Secrets From the Magaji -- was thinking about 4-5, but 3 is a good number, you draw too much attention if you put it on too early 2x Restoration Equipment (5) 1x Ivory Bow 1x Kduva's Mask 1x Reliquary: Akunanse Remains 2x Sniper Rifle Political Action (4) 1x Anarchist Uprising 1x Ancilla Empowerment -- nobody really expects these 2 until its too late 2x Secret Must Be Kept, The -- amazing card against any ally deck Retainer (6) 5x Raven Spy 1x Shaman Action Modifier (12) 7x Freak Drive 4x Predator's Mastery -- lovely thanks to several ally decks playing 1x Strange Day -- won me the final pretty much Action Modifier/Combat (5) 5x Predator's Transformation -- wonderful card, can play it anytime, and the bonus superior effect did help a lot many times Action Modifier/Reaction (1) 1x Akunanse Kholo Reaction (4) 4x Predator's Communion -- very helpful before you get no secrets, easy to drop afterwards Combat (27) 2x Canine Horde -- crucial in the final 5x Carrion Crows 2x Flesh Bond -- butt-saver 5x Invoking the Beast 4x Rolling with the Punches 3x Skin of Steel 2x Superior Mettle -- I'd revise the prevent cards anyway, maybe adding some with no cost, or more of SM. it worked nice in overall though 4x Taste of Vitae